@@ -6,8 +6,9 @@ class Request:
     """This is the Request object that contains the tricky stuff 
     for a http request"""
     def __init__(self, url='', post=None, referer=None, 
-            proxy=None, extraheaders={}, forbid_redirect=False,
-            trycount=None, fd=None, onprogress=None, only_head=False, multipart=False, method = "GET"):
+            proxy=None, headers={}, forbid_redirect=False,
+            trycount=None, fd=None, onprogress=None, only_head=False, multipart=False, 
+            method = "GET"):
         """Download an URL with GET or POST methods.
 
         @param post: It can be a string that will be POST-ed to the URL.
@@ -54,7 +55,7 @@ class Request:
         self.post = post
         self.proxy = proxy
         self.tries = 0
-        self.headers = {}
+        self.headers = headers
         self.only_head = only_head
         
         return None    
